lstart <-
function (basedir = "latex", filename = "main.tex", overwrite = FALSE, 
    headerfiles = NULL, bodyfiles = NULL, packages = c("fullpage", 
        "verbatim", "graphicx", "amsfonts", "amsmath", "mathrsfs", 
        "yfonts", "placeins", "hyperref", "rotating", "subcaption"), 
    clean = TRUE) 
{
    if (clean) {
        if (exists("htmllatexlock")) 
            detach(htmllatexbase)
    }
    if (file.exists(basedir)) {
        if (overwrite) {
            unlink(basedir, recursive = TRUE)
        }
        else {
            cat("Basedir already exists.\n")
            return(NULL)
        }
    }
    if (!exists("htmllatexlock")) {
        htmllatexlock = TRUE
        htmllatexenv = new.env(parent = globalenv())
        htmllatexbase = list(htmllatexenv = htmllatexenv, htmllatexlock = htmllatexlock)
        attach(htmllatexbase)
    }
    latexpage = list(basedir = NULL, filename = NULL, file = NULL, 
        active = TRUE)
    if (!exists("latexpages", where = htmllatexenv)) {
        htmllatexenv$latexpages = list(latexpage)
        pagenum = 1
    }
    else {
        htmllatexenv$latexpages = c(htmllatexenv$latexpages, 
            list(latexpage))
        pagenum = length(htmllatexenv$latexpages)
    }
    dir.create(basedir)
    htmllatexenv$latexpages[[pagenum]]$basedir = basedir
    htmllatexenv$latexpages[[pagenum]]$filename = filename
    htmllatexenv$latexpages[[pagenum]]$file = paste(basedir, 
        filename, sep = "/")
    lcat("\\documentclass{article}\n", pagenum = pagenum)
    for (package in packages) {
        lcat("\\usepackage{", package, "}\n", pagenum = pagenum)
    }
    if (!is.null(headerfiles)) 
        for (headerfile in headerfiles) lmerge(headerfile, pagenum = pagenum)
    lcat("\\begin{document}\n", pagenum = pagenum)
    if (!is.null(bodyfiles)) 
        for (bodyfile in bodyfiles) lmerge(bodyfile, pagenum = pagenum)
    return(pagenum)
}
