ltabletable <-
function (tablelist, headers = NULL, caption = NULL, shortcaption = NULL, 
    label = NULL, scale = "1.0", rnames = TRUE, cnames = TRUE, 
    justify = NULL, interpadding = NULL, bottompadding = NULL, 
    sideways = FALSE, pagenum = 1) 
{
    m = length(tablelist)
    n = length(tablelist[[1]])
    if (sideways) 
        lcat("\\begin{sidewaystable}[h]\n", pagenum = pagenum)
    else lcat("\\begin{table}[h]\n", pagenum = pagenum)
    lcat("\\begin{center}\n", pagenum = pagenum)
    lcat("\\begin{tabular}{", rep("c", n), "}\n", pagenum = pagenum)
    for (i in 1:m) {
        if (!is.null(headers)) {
            for (j in 1:n) {
                lcat(headers[i, j], pagenum = pagenum)
                if (j < n) 
                  lcat("\t&\t", pagenum = pagenum)
                else lcat("\\\\\n", pagenum = pagenum)
            }
        }
        for (j in 1:n) {
            lcat("\\scalebox{", scale, "}{\n", pagenum = pagenum)
            lsimpletable(tablelist[[i]][[j]], rnames = rnames, 
                cnames = cnames, justify = justify, pagenum = pagenum)
            if (j < n) 
                lcat("} &\n", pagenum = pagenum)
            else {
                if (i < m) {
                  if (is.null(interpadding)) 
                    lcat("} \\\\\\\\\n", pagenum = pagenum)
                  else lcat("} \\\\\\\\\\noalign{\\vspace{", 
                    interpadding, "mm}}\n", pagenum = pagenum)
                }
                else {
                  if (is.null(bottompadding)) 
                    lcat("}\n", pagenum = pagenum)
                  else lcat("} \\\\\\noalign{\\vspace{", bottompadding, 
                    "mm}}\n", pagenum = pagenum)
                }
            }
        }
    }
    lcat("\\end{tabular}\n", pagenum = pagenum)
    lcat("\\end{center}\n", pagenum = pagenum)
    if (!is.null(shortcaption)) {
        if (!is.null(caption)) {
            lcat("\\caption[", shortcaption, "]{", caption, "}\n", 
                pagenum = pagenum)
        }
        else {
            lcat("\\caption[", shortcaption, "]{", shortcaption, 
                "}\n", pagenum = pagenum)
        }
    }
    else {
        if (!is.null(caption)) {
            lcat("\\caption{", caption, "}\n", pagenum = pagenum)
        }
    }
    if (!is.null(label)) {
        lcat("\\label{", label, "}\n", pagenum = pagenum)
    }
    if (sideways) 
        lcat("\\end{sidewaystable}\n\n", pagenum = pagenum)
    else lcat("\\end{table}\n\n", pagenum = pagenum)
}
